"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ShipmentExtraReturnServiceTypeLasershipEnum(str, Enum):
    NO_RETURN = 'NO_RETURN'
