"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelBetterTrucksEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | better_trucks_same_day | Same Day|
    | better_trucks_next_day | Next Day|
    """
    BETTER_TRUCKS_SAME_DAY = 'better_trucks_same_day'
    BETTER_TRUCKS_NEXT_DAY = 'better_trucks_next_day'
