"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelDHLExpressEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | dhl_express_domestic_express_doc | Domestic Express Doc|
    | dhl_express_economy_select_doc | Economy Select Doc|
    | dhl_express_worldwide_nondoc | Express Worldwide Nondoc|
    | dhl_express_worldwide_doc | Express Worldwide Doc|
    | dhl_express_worldwide | Worldwide|
    | dhl_express_worldwide_eu_doc | Express Worldwide EU Doc|
    | dhl_express_break_bulk_express_doc | Break Bulk Express Doc|
    | dhl_express_express_9_00_nondoc | Express 9:00 NonDoc|
    | dhl_express_economy_select_nondoc | Economy Select NonDoc|
    | dhl_express_break_bulk_economy_doc | Break Bulk Economy Doc|
    | dhl_express_express_9_00_doc | Express 9:00 Doc|
    | dhl_express_express_10_30_doc | Express 10:30 Doc|
    | dhl_express_express_10_30_nondoc | Express 10:30 NonDoc|
    | dhl_express_express_12_00_doc | Express 12:00 Doc|
    | dhl_express_europack_nondoc | Europack NonDoc|
    | dhl_express_express_envelope_doc | Express Envelope Doc|
    | dhl_express_express_12_00_nondoc | Express 12:00 NonDoc|
    | dhl_express_express_12_doc | Domestic Express 12:00|
    | dhl_express_worldwide_b2c_doc | Express Worldwide (B2C) Doc|
    | dhl_express_worldwide_b2c_nondoc | Express Worldwide (B2C) NonDoc|
    | dhl_express_medical_express | Medical Express|
    | dhl_express_express_easy_nondoc | Express Easy NonDoc|
    """
    DHL_EXPRESS_DOMESTIC_EXPRESS_DOC = 'dhl_express_domestic_express_doc'
    DHL_EXPRESS_ECONOMY_SELECT_DOC = 'dhl_express_economy_select_doc'
    DHL_EXPRESS_WORLDWIDE_NONDOC = 'dhl_express_worldwide_nondoc'
    DHL_EXPRESS_WORLDWIDE_DOC = 'dhl_express_worldwide_doc'
    DHL_EXPRESS_WORLDWIDE = 'dhl_express_worldwide'
    DHL_EXPRESS_WORLDWIDE_EU_DOC = 'dhl_express_worldwide_eu_doc'
    DHL_EXPRESS_BREAK_BULK_EXPRESS_DOC = 'dhl_express_break_bulk_express_doc'
    DHL_EXPRESS_EXPRESS_9_00_NONDOC = 'dhl_express_express_9_00_nondoc'
    DHL_EXPRESS_ECONOMY_SELECT_NONDOC = 'dhl_express_economy_select_nondoc'
    DHL_EXPRESS_BREAK_BULK_ECONOMY_DOC = 'dhl_express_break_bulk_economy_doc'
    DHL_EXPRESS_EXPRESS_9_00_DOC = 'dhl_express_express_9_00_doc'
    DHL_EXPRESS_EXPRESS_10_30_DOC = 'dhl_express_express_10_30_doc'
    DHL_EXPRESS_EXPRESS_10_30_NONDOC = 'dhl_express_express_10_30_nondoc'
    DHL_EXPRESS_EXPRESS_12_00_DOC = 'dhl_express_express_12_00_doc'
    DHL_EXPRESS_EUROPACK_NONDOC = 'dhl_express_europack_nondoc'
    DHL_EXPRESS_EXPRESS_ENVELOPE_DOC = 'dhl_express_express_envelope_doc'
    DHL_EXPRESS_EXPRESS_12_00_NONDOC = 'dhl_express_express_12_00_nondoc'
    DHL_EXPRESS_EXPRESS_12_DOC = 'dhl_express_express_12_doc'
    DHL_EXPRESS_WORLDWIDE_B2C_DOC = 'dhl_express_worldwide_b2c_doc'
    DHL_EXPRESS_WORLDWIDE_B2C_NONDOC = 'dhl_express_worldwide_b2c_nondoc'
    DHL_EXPRESS_MEDICAL_EXPRESS = 'dhl_express_medical_express'
    DHL_EXPRESS_EXPRESS_EASY_NONDOC = 'dhl_express_express_easy_nondoc'
