"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelSendleEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | sendle_parcel | Sendle Parcel|
    | sendle_standard_dropoff | Sendle Standard Dropoff|
    """
    SENDLE_PARCEL = 'sendle_parcel'
    SENDLE_STANDARD_DROPOFF = 'sendle_standard_dropoff'
