"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelGLSUSEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | gls_us_cps | GSO Ground|
    | gls_us_eps | Early Priority Overnight|
    | gls_us_ess | Early Saturday Delivery|
    | gls_us_nps | Noon Priority Overnight|
    | gls_us_pds | Priority Overnight|
    | gls_us_sds | Saturday Delivery|
    """
    GLS_US_CPS = 'gls_us_cps'
    GLS_US_EPS = 'gls_us_eps'
    GLS_US_ESS = 'gls_us_ess'
    GLS_US_NPS = 'gls_us_nps'
    GLS_US_PDS = 'gls_us_pds'
    GLS_US_SDS = 'gls_us_sds'
