"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelColissimoEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | colissimo_home | Domicile|
    | colissimo_pick_up_point | Point Retrait|
    | colissimo_return_mainland_france | Retour France|
    """
    COLISSIMO_HOME = 'colissimo_home'
    COLISSIMO_PICK_UP_POINT = 'colissimo_pick_up_point'
    COLISSIMO_RETURN_MAINLAND_FRANCE = 'colissimo_return_mainland_france'
