"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelPostItalianeEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | poste_italiane_delivery_business_express | Poste Delivery Business Express|
    """
    POSTE_ITALIANE_DELIVERY_BUSINESS_EXPRESS = 'poste_italiane_delivery_business_express'
