"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelDeutschePostEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | deutsche_post_postkarte | Postkarte|
    | deutsche_post_standardbrief | Standardbrief|
    | deutsche_post_kompaktbrief | Kompaktbrief|
    | deutsche_post_grossbrief | Grossbrief|
    | deutsche_post_maxibrief | Maxibrief|
    | deutsche_post_maxibrief_plus | Maxibrief Plus|
    | deutsche_post_warenpost_international_xs | Warenpost International XS|
    | deutsche_post_warenpost_international_s | Warenpost International S|
    | deutsche_post_warenpost_international_m | Warenpost International M|
    | deutsche_post_warenpost_international_l | Warenpost International L|
    """
    DEUTSCHE_POST_POSTKARTE = 'deutsche_post_postkarte'
    DEUTSCHE_POST_STANDARDBRIEF = 'deutsche_post_standardbrief'
    DEUTSCHE_POST_KOMPAKTBRIEF = 'deutsche_post_kompaktbrief'
    DEUTSCHE_POST_GROSSBRIEF = 'deutsche_post_grossbrief'
    DEUTSCHE_POST_MAXIBRIEF = 'deutsche_post_maxibrief'
    DEUTSCHE_POST_MAXIBRIEF_PLUS = 'deutsche_post_maxibrief_plus'
    DEUTSCHE_POST_WARENPOST_INTERNATIONAL_XS = 'deutsche_post_warenpost_international_xs'
    DEUTSCHE_POST_WARENPOST_INTERNATIONAL_S = 'deutsche_post_warenpost_international_s'
    DEUTSCHE_POST_WARENPOST_INTERNATIONAL_M = 'deutsche_post_warenpost_international_m'
    DEUTSCHE_POST_WARENPOST_INTERNATIONAL_L = 'deutsche_post_warenpost_international_l'
