"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelAramexAustraliaEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | fastway_australia_parcel | Parcel|
    | fastway_australia_satchel | Satchel|
    | fastway_australia_box_small | Box Small|
    | fastway_australia_box_medium | Box Medium|
    | fastway_australia_box_large | Box Large|
    """
    FASTWAY_AUSTRALIA_PARCEL = 'fastway_australia_parcel'
    FASTWAY_AUSTRALIA_SATCHEL = 'fastway_australia_satchel'
    FASTWAY_AUSTRALIA_BOX_SMALL = 'fastway_australia_box_small'
    FASTWAY_AUSTRALIA_BOX_MEDIUM = 'fastway_australia_box_medium'
    FASTWAY_AUSTRALIA_BOX_LARGE = 'fastway_australia_box_large'
