"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ShipmentExtraLasershipAttributesEnum(str, Enum):
    TWO_PERSON_DELIVERY = 'TwoPersonDelivery'
    EXPLOSIVE = 'Explosive'
    ALCOHOL = 'Alcohol'
    HAZMAT = 'Hazmat'
    CONTROLLED_SUBSTANCE = 'ControlledSubstance'
    REFRIGERATED = 'Refrigerated'
    DRY_ICE = 'DryIce'
    PERISHABLE = 'Perishable'
    NO_RTS = 'NoRTS'
