"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelChronopostEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | chronopost_13 | Chrono 13|
    | chronopost_10 | Chrono 10|
    | chronopost_18| Chrono 18|
    | chronopost_relais_fr | Chrono Point Relais|
    | chronopost_classic | Chrono Classic International|
    | chronopost_express | Chrono Express International|
    """
    CHRONOPOST_13 = 'chronopost_13'
    CHRONOPOST_10 = 'chronopost_10'
    CHRONOPOST_18 = 'chronopost_18'
    CHRONOPOST_RELAIS_FR = 'chronopost_relais_fr'
    CHRONOPOST_CLASSIC = 'chronopost_classic'
    CHRONOPOST_EXPRESS = 'chronopost_express'
