"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelOnTracEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | ontrac_ground | Ground|
    | ontrac_sunrise_gold | Sunrise Gold|
    | ontrac_sunrise | Sunrise|
    """
    ONTRAC_GROUND = 'ontrac_ground'
    ONTRAC_SUNRISE_GOLD = 'ontrac_sunrise_gold'
    ONTRAC_SUNRISE = 'ontrac_sunrise'
