"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class WeightUnitEnum(str, Enum):
    r"""The unit used for weight."""
    G = 'g'
    KG = 'kg'
    LB = 'lb'
    OZ = 'oz'
