"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ShipmentExtraReturnServiceTypeUPSEnum(str, Enum):
    PRINT_AND_MAIL = 'PRINT_AND_MAIL'
    ATTEMPT_1 = 'ATTEMPT_1'
    ATTEMPT_3 = 'ATTEMPT_3'
    ELECTRONIC_LABEL = 'ELECTRONIC_LABEL'
