"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelAirterraEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | airterra_ground | GroundXC|
    | airterra_postal | FastPost|
    """
    AIRTERRA_GROUND = 'airterra_ground'
    AIRTERRA_POSTAL = 'airterra_postal'
