"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ParcelTemplateUPSEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | UPS_Box_10kg | Box 10kg | 410.00 x 335.00 x 265.00 mm|
    | UPS_Box_25kg | Box 25kg | 484.00 x 433.00 x 350.00 mm|
    | UPS_Express_Box | Express Box | 460.00 x 315.00 x 95.00 mm|
    | UPS_Express_Box_Large | Express Box Large | 18.00 x 13.00 x 3.00 in|
    | UPS_Express_Box_Medium | Express Box Medium | 15.00 x 11.00 x 3.00 in|
    | UPS_Express_Box_Small | Express Box Small | 13.00 x 11.00 x 2.00 in|
    | UPS_Express_Envelope | Express Envelope | 12.50 x 9.50 x 2.00 in|
    | UPS_Express_Hard_Pak | Express Hard Pak | 14.75 x 11.50 x 2.00 in|
    | UPS_Express_Legal_Envelope | Express Legal Envelope | 15.00 x 9.50 x 2.00 in|
    | UPS_Express_Pak | Express Pak | 16.00 x 12.75 x 2.00 in|
    | UPS_Express_Tube | Express Tube | 970.00 x 190.00 x 165.00 mm|
    | UPS_Laboratory_Pak | Laboratory Pak | 17.25 x 12.75 x 2.00 in|
    | UPS_MI_BPM | BPM (Mail Innovations - Domestic &amp; International) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_BPM_Flat | BPM Flat (Mail Innovations - Domestic &amp; International) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_BPM_Parcel | BPM Parcel (Mail Innovations - Domestic &amp; International) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_First_Class | First Class (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Flat | Flat (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Irregular | Irregular (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Machinable | Machinable (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_MEDIA_MAIL | Media Mail (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Parcel_Post | Parcel Post (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Priority | Priority (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Standard_Flat | Standard Flat (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_Pad_Pak | Pad Pak | 14.75 x 11.00 x 2.00 in|
    | UPS_Pallet | Pallet | 120.00 x 80.00 x 200.00 cm|
    """
    UPS_BOX_10KG = 'UPS_Box_10kg'
    UPS_BOX_25KG = 'UPS_Box_25kg'
    UPS_EXPRESS_BOX = 'UPS_Express_Box'
    UPS_EXPRESS_BOX_LARGE = 'UPS_Express_Box_Large'
    UPS_EXPRESS_BOX_MEDIUM = 'UPS_Express_Box_Medium'
    UPS_EXPRESS_BOX_SMALL = 'UPS_Express_Box_Small'
    UPS_EXPRESS_ENVELOPE = 'UPS_Express_Envelope'
    UPS_EXPRESS_HARD_PAK = 'UPS_Express_Hard_Pak'
    UPS_EXPRESS_LEGAL_ENVELOPE = 'UPS_Express_Legal_Envelope'
    UPS_EXPRESS_PAK = 'UPS_Express_Pak'
    UPS_EXPRESS_TUBE = 'UPS_Express_Tube'
    UPS_LABORATORY_PAK = 'UPS_Laboratory_Pak'
    UPS_MI_BPM = 'UPS_MI_BPM'
    UPS_MI_BPM_FLAT = 'UPS_MI_BPM_Flat'
    UPS_MI_BPM_PARCEL = 'UPS_MI_BPM_Parcel'
    UPS_MI_FIRST_CLASS = 'UPS_MI_First_Class'
    UPS_MI_FLAT = 'UPS_MI_Flat'
    UPS_MI_IRREGULAR = 'UPS_MI_Irregular'
    UPS_MI_MACHINABLE = 'UPS_MI_Machinable'
    UPS_MI_MEDIA_MAIL = 'UPS_MI_MEDIA_MAIL'
    UPS_MI_PARCEL_POST = 'UPS_MI_Parcel_Post'
    UPS_MI_PRIORITY = 'UPS_MI_Priority'
    UPS_MI_STANDARD_FLAT = 'UPS_MI_Standard_Flat'
    UPS_PAD_PAK = 'UPS_Pad_Pak'
    UPS_PALLET = 'UPS_Pallet'
