"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelPurolatorEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | purolator_ground | Ground|
    | purolator_ground9_am | Ground 9am|
    | purolator_ground1030_am | Ground 10:30am|
    | purolator_ground_distribution | Ground Distribution|
    | purolator_ground_evening | Ground Evening|
    | purolator_ground_us | Ground US|
    | purolator_express | Express|
    | purolator_express9_am | Express 9am|
    | purolator_express1030_am | Express 10am|
    | purolator_express_evening | Express Evening|
    | purolator_express_us | Express US|
    | purolator_express_us9_am | Express US 9am|
    | purolator_express_us1030_am | Express US 10:30am|
    | purolator_express_us1200 | Express US 12pm|
    | purolator_express_international | Express International|
    | purolator_express_international9_am | Express International 9am|
    | purolator_express_international1030_am | Express International 10:30am|
    | purolator_express_international1200 | Express International 12pm|
    """
    PUROLATOR_GROUND = 'purolator_ground'
    PUROLATOR_GROUND9_AM = 'purolator_ground9_am'
    PUROLATOR_GROUND1030_AM = 'purolator_ground1030_am'
    PUROLATOR_GROUND_DISTRIBUTION = 'purolator_ground_distribution'
    PUROLATOR_GROUND_EVENING = 'purolator_ground_evening'
    PUROLATOR_GROUND_US = 'purolator_ground_us'
    PUROLATOR_EXPRESS = 'purolator_express'
    PUROLATOR_EXPRESS9_AM = 'purolator_express9_am'
    PUROLATOR_EXPRESS1030_AM = 'purolator_express1030_am'
    PUROLATOR_EXPRESS_EVENING = 'purolator_express_evening'
    PUROLATOR_EXPRESS_US = 'purolator_express_us'
    PUROLATOR_EXPRESS_US9_AM = 'purolator_express_us9_am'
    PUROLATOR_EXPRESS_US1030_AM = 'purolator_express_us1030_am'
    PUROLATOR_EXPRESS_US1200 = 'purolator_express_us1200'
    PUROLATOR_EXPRESS_INTERNATIONAL = 'purolator_express_international'
    PUROLATOR_EXPRESS_INTERNATIONAL9_AM = 'purolator_express_international9_am'
    PUROLATOR_EXPRESS_INTERNATIONAL1030_AM = 'purolator_express_international1030_am'
    PUROLATOR_EXPRESS_INTERNATIONAL1200 = 'purolator_express_international1200'
