"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelCorreosEspanaEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | correos_standard_home| Paquete Estándar|
    | correos_premium_home | Paquete Premium|
    """
    CORREOS_STANDARD_HOME = 'correos_standard_home'
    CORREOS_PREMIUM_HOME = 'correos_premium_home'
