"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelUPSEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | ups_standard | Standard℠|
    | ups_ground | Ground|
    | ups_saver | Saver®|
    | ups_3_day_select | 3 Day Select®|
    | ups_second_day_air | 2nd Day Air®|
    | ups_second_day_air_am | 2nd Day Air® A.M.|
    | ups_next_day_air | Next Day Air®|
    | ups_next_day_air_saver | Next Day Air Saver®|
    | ups_next_day_air_early_am | Next Day Air® Early|
    | ups_mail_innovations_bpm_flat | Mail Innovations BPM Flat |
    | ups_mail_innovations_bpm_parcel | Mail Innovations BPM Parcel |
    | ups_mail_innovations_irregular | Mail Innovations Irregular |
    | ups_mail_innovations_media_mail | Mail Innovations Media Mail |
    | ups_mail_innovations_parcel | Mail Innovations Parcel |
    | ups_mail_innovations_standard_flat | Mail Innovations Standard Flat |
    | ups_surepost | Surepost|
    | ups_surepost_bound_printed_matter | SurePost® Bound Printed Matter|
    | ups_surepost_lightweight | Surepost Lightweight|
    | ups_surepost_media | SurePost® Media|
    | ups_express | Express®|
    | ups_express_1200 | Express 12:00|
    | ups_express_plus | Express Plus®|
    | ups_expedited | Expedited®|
    | ups_express_early | Express® Early|
    | ups_access_point_economy | Access Point™ Economy|
    """
    UPS_STANDARD = 'ups_standard'
    UPS_GROUND = 'ups_ground'
    UPS_SAVER = 'ups_saver'
    UPS_3_DAY_SELECT = 'ups_3_day_select'
    UPS_SECOND_DAY_AIR = 'ups_second_day_air'
    UPS_SECOND_DAY_AIR_AM = 'ups_second_day_air_am'
    UPS_NEXT_DAY_AIR = 'ups_next_day_air'
    UPS_NEXT_DAY_AIR_SAVER = 'ups_next_day_air_saver'
    UPS_NEXT_DAY_AIR_EARLY_AM = 'ups_next_day_air_early_am'
    UPS_MAIL_INNOVATIONS_BPM_FLAT = 'ups_mail_innovations_bpm_flat'
    UPS_MAIL_INNOVATIONS_BPM_PARCEL = 'ups_mail_innovations_bpm_parcel'
    UPS_MAIL_INNOVATIONS_IRREGULAR = 'ups_mail_innovations_irregular'
    UPS_MAIL_INNOVATIONS_MEDIA_MAIL = 'ups_mail_innovations_media_mail'
    UPS_MAIL_INNOVATIONS_PARCEL = 'ups_mail_innovations_parcel'
    UPS_MAIL_INNOVATIONS_STANDARD_FLAT = 'ups_mail_innovations_standard_flat'
    UPS_SUREPOST = 'ups_surepost'
    UPS_SUREPOST_BOUND_PRINTED_MATTER = 'ups_surepost_bound_printed_matter'
    UPS_SUREPOST_LIGHTWEIGHT = 'ups_surepost_lightweight'
    UPS_SUREPOST_MEDIA = 'ups_surepost_media'
    UPS_EXPRESS = 'ups_express'
    UPS_EXPRESS_1200 = 'ups_express_1200'
    UPS_EXPRESS_PLUS = 'ups_express_plus'
    UPS_EXPEDITED = 'ups_expedited'
    UPS_EXPRESS_EARLY = 'ups_express_early'
    UPS_ACCESS_POINT_ECONOMY = 'ups_access_point_economy'
