"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelDPDDEEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | dpd_de_classic | DPD Classic|
    """
    DPD_DE_CLASSIC = 'dpd_de_classic'
