"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelGlobegisticsEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | globegistics_priority_mail_express_international | Globegistics Priority Mail Express International|
    | globegistics_priority_mail_international | Globegistics Priority Mail International|
    | globegistics_priority_mail_express_international_pds | Globegistics Priority Mail Express International PreSort Drop Ship|
    | globegistics_priority_mail_international_pds | Globegistics Priority Mail International PreSort Drop Ship|
    | globegistics_epacket | Globegistics ePacket|
    | globegistics_ecom_tracked_ddp | Globegistics eCom Tracked DDP|
    | globegistics_ecom_packet_ddp | Globegistics eCom Packet DDP|
    | globegistics_ecom_priority_mail_international_ddp | Globegistics eCom Priority Mail International DDP|
    | globegistics_ecom_priority_mail_express_international_ddp | Globegistics eCom Priority Mail Express International DDP|
    | globegistics_ecom_extra | Globegistics eCom Extra|
    | globegistics_ecom_international_priority_airmail | Globegistics eCom International Priority Airmail|
    | globegistics_ecom_international_surface_airlift | Globegistics eCom International Surface Air Lift|
    """
    GLOBEGISTICS_PRIORITY_MAIL_EXPRESS_INTERNATIONAL = 'globegistics_priority_mail_express_international'
    GLOBEGISTICS_PRIORITY_MAIL_INTERNATIONAL = 'globegistics_priority_mail_international'
    GLOBEGISTICS_PRIORITY_MAIL_EXPRESS_INTERNATIONAL_PDS = 'globegistics_priority_mail_express_international_pds'
    GLOBEGISTICS_PRIORITY_MAIL_INTERNATIONAL_PDS = 'globegistics_priority_mail_international_pds'
    GLOBEGISTICS_EPACKET = 'globegistics_epacket'
    GLOBEGISTICS_ECOM_TRACKED_DDP = 'globegistics_ecom_tracked_ddp'
    GLOBEGISTICS_ECOM_PACKET_DDP = 'globegistics_ecom_packet_ddp'
    GLOBEGISTICS_ECOM_PRIORITY_MAIL_INTERNATIONAL_DDP = 'globegistics_ecom_priority_mail_international_ddp'
    GLOBEGISTICS_ECOM_PRIORITY_MAIL_EXPRESS_INTERNATIONAL_DDP = 'globegistics_ecom_priority_mail_express_international_ddp'
    GLOBEGISTICS_ECOM_EXTRA = 'globegistics_ecom_extra'
    GLOBEGISTICS_ECOM_INTERNATIONAL_PRIORITY_AIRMAIL = 'globegistics_ecom_international_priority_airmail'
    GLOBEGISTICS_ECOM_INTERNATIONAL_SURFACE_AIRLIFT = 'globegistics_ecom_international_surface_airlift'
