"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelAsendiaEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | asendia_us_priority_tracked | Asendia USA Priority Tracked|
    | asendia_us_international_express | Asendia USA International Express|
    | asendia_us_international_priority_airmail | Asendia USA International Priority Airmail|
    | asendia_us_international_surface_airlift | Asendia USA International Surface Air Lift|
    | asendia_us_priority_mail_international | Asendia USA Priority Mail International|
    | asendia_us_priority_mail_express_international | Asendia USA Priority Mail Express International|
    | asendia_us_epacket | Asendia USA International ePacket|
    | asendia_us_other | Asendia USA Other Services (custom)|
    """
    ASENDIA_US_PRIORITY_TRACKED = 'asendia_us_priority_tracked'
    ASENDIA_US_INTERNATIONAL_EXPRESS = 'asendia_us_international_express'
    ASENDIA_US_INTERNATIONAL_PRIORITY_AIRMAIL = 'asendia_us_international_priority_airmail'
    ASENDIA_US_INTERNATIONAL_SURFACE_AIRLIFT = 'asendia_us_international_surface_airlift'
    ASENDIA_US_PRIORITY_MAIL_INTERNATIONAL = 'asendia_us_priority_mail_international'
    ASENDIA_US_PRIORITY_MAIL_EXPRESS_INTERNATIONAL = 'asendia_us_priority_mail_express_international'
    ASENDIA_US_EPACKET = 'asendia_us_epacket'
    ASENDIA_US_OTHER = 'asendia_us_other'
