"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelVehoEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | veho_next_day | Veho Next Day |
    """
    VEHO_NEXT_DAY = 'veho_next_day'
