"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .webhookpayloadbatch import WebhookPayloadBatch
from .webhookpayloadtrack import WebhookPayloadTrack
from .webhookpayloadtransaction import WebhookPayloadTransaction
from typing import Union

WebhookPayload = Union[WebhookPayloadTrack, WebhookPayloadBatch, WebhookPayloadTransaction]
