"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CustomsDeclarationNonDeliveryOptionEnum(str, Enum):
    r"""Indicates how the carrier should proceed in case the shipment can't be delivered.
    Allowed values available <a href=\"#tag/Customs-Declaration-Non-Delivery-Option\">here</a>
    """
    ABANDON = 'ABANDON'
    RETURN = 'RETURN'
