"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelFedExEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | fedex_ground | FedEx Ground®|
    | fedex_home_delivery | FedEx Home Delivery®|
    | fedex_ground_economy | FedEx Ground® Economy|
    | fedex_2_day | FedEx 2Day®|
    | fedex_2_day_am | FedEx 2Day® A.M.|
    | fedex_express_saver | FedEx Express Saver®|
    | fedex_standard_overnight | FedEx Standard Overnight®|
    | fedex_priority_overnight | FedEx Priority Overnight®|
    | fedex_first_overnight | FedEx First Overnight®|
    | fedex_international_economy | FedEx International Economy®|
    | fedex_international_priority | FedEx International Priority®|
    | fedex_international_first | FedEx International First®|
    | fedex_europe_first_international_priority | FedEx International First®|
    | fedex_international_connect_plus | FedEx International Connect Plus|
    | fedex_first | FedEx First |
    | fedex_priority | FedEx Priority |
    | fedex_priority_express | FedEx Priority Express|
    | fedex_economy_select | FedEx® Economy |
    | fedex_regional_economy | FedEx® Regional Economy |
    | fedex_first_overnight_extra_hours | First Overnight® EH |
    | fedex_international_priority_express | International Priority® Express |
    | fedex_next_day_mid_morning | Next Day Mid Morning |
    | fedex_priority_overnight_extra_hours | Priority Overnight® EH |
    | fedex_standard_overnight_extra_hours | Standard Overnight® EH |
    """
    FEDEX_GROUND = 'fedex_ground'
    FEDEX_HOME_DELIVERY = 'fedex_home_delivery'
    FEDEX_SMART_POST = 'fedex_smart_post'
    FEDEX_GROUND_ECONOMY = 'fedex_ground_economy'
    FEDEX_2_DAY = 'fedex_2_day'
    FEDEX_2_DAY_AM = 'fedex_2_day_am'
    FEDEX_EXPRESS_SAVER = 'fedex_express_saver'
    FEDEX_STANDARD_OVERNIGHT = 'fedex_standard_overnight'
    FEDEX_PRIORITY_OVERNIGHT = 'fedex_priority_overnight'
    FEDEX_FIRST_OVERNIGHT = 'fedex_first_overnight'
    FEDEX_INTERNATIONAL_ECONOMY = 'fedex_international_economy'
    FEDEX_INTERNATIONAL_PRIORITY = 'fedex_international_priority'
    FEDEX_INTERNATIONAL_FIRST = 'fedex_international_first'
    FEDEX_EUROPE_FIRST_INTERNATIONAL_PRIORITY = 'fedex_europe_first_international_priority'
    FEDEX_INTERNATIONAL_CONNECT_PLUS = 'fedex_international_connect_plus'
    FEDEX_FIRST = 'fedex_first'
    FEDEX_PRIORITY = 'fedex_priority'
    FEDEX_PRIORITY_EXPRESS = 'fedex_priority_express'
    FEDEX_ECONOMY_SELECT = 'fedex_economy_select'
    FEDEX_REGIONAL_ECONOMY = 'fedex_regional_economy'
    FEDEX_FIRST_OVERNIGHT_EXTRA_HOURS = 'fedex_first_overnight_extra_hours'
    FEDEX_INTERNATIONAL_PRIORITY_EXPRESS = 'fedex_international_priority_express'
    FEDEX_NEXT_DAY_MID_MORNING = 'fedex_next_day_mid_morning'
    FEDEX_PRIORITY_OVERNIGHT_EXTRA_HOURS = 'fedex_priority_overnight_extra_hours'
    FEDEX_STANDARD_OVERNIGHT_EXTRA_HOURS = 'fedex_standard_overnight_extra_hours'
