"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .parceltemplatearamexaustraliaenum import ParcelTemplateAramexAustraliaEnum
from .parceltemplatecourierspleaseenum import ParcelTemplateCouriersPleaseEnum
from .parceltemplatedhlecommerceenum import ParcelTemplateDHLeCommerceEnum
from .parceltemplatedpdukenum import ParcelTemplateDPDUKEnum
from .parceltemplatefedexenum import ParcelTemplateFedExEnum
from .parceltemplateupsenum import ParcelTemplateUPSEnum
from .parceltemplateuspsenum import ParcelTemplateUSPSEnum
from typing import Union

ParcelTemplateEnumSet = Union[ParcelTemplateFedExEnum, ParcelTemplateUPSEnum, ParcelTemplateUSPSEnum, ParcelTemplateDHLeCommerceEnum, ParcelTemplateDPDUKEnum, ParcelTemplateCouriersPleaseEnum, ParcelTemplateAramexAustraliaEnum]
