"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .userparceltemplatewithcarriertemplatecreaterequest import UserParcelTemplateWithCarrierTemplateCreateRequest
from .userparceltemplatewithoutcarriertemplatecreaterequest import UserParcelTemplateWithoutCarrierTemplateCreateRequest
from typing import Union

UserParcelTemplateCreateRequest = Union[UserParcelTemplateWithCarrierTemplateCreateRequest, UserParcelTemplateWithoutCarrierTemplateCreateRequest]
