"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class WebhookEventTypeEnum(str, Enum):
    r"""Type of event that triggered the webhook."""
    TRANSACTION_CREATED = 'transaction_created'
    TRANSACTION_UPDATED = 'transaction_updated'
    TRACK_UPDATED = 'track_updated'
    BATCH_CREATED = 'batch_created'
    BATCH_PURCHASED = 'batch_purchased'
    ALL = 'all'
