"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class OrderShopAppEnum(str, Enum):
    r"""Platform the order was created on and, if applicable, imported from.
    Orders created via the Shippo API or dashboard will have the value \"Shippo\".
    """
    AMAZON = 'Amazon'
    BIGCOMMERCE = 'Bigcommerce'
    CSV_IMPORT = 'CSV_Import'
    E_BAY = 'eBay'
    E_PAGES = 'ePages'
    ETSY = 'Etsy'
    GODADDY = 'Godaddy'
    MAGENTO = 'Magento'
    SHIPPO = 'Shippo'
    SHOPIFY = 'Shopify'
    SPREECOMMERCE = 'Spreecommerce'
    STRIPE_RELAY = 'StripeRelay'
    WALMART = 'Walmart'
    WEEBLY = 'Weebly'
    WOO_COMMERCE = 'WooCommerce'
