"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelLasershipEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | lasership_routed_delivery | Routed Delivery|
    """
    LASERSHIP_ROUTED_DELIVERY = 'lasership_routed_delivery'
