"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ParcelTemplateCouriersPleaseEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | couriersplease_500g_satchel | 500g Satchel | 22.00 x 33.50 x 0.10 cm|
    | couriersplease_1kg_satchel | 1kg Satchel | 28.00 x 35.00 x 0.10 cm|
    | couriersplease_3kg_satchel | 3kg Satchel | 34.00 x 42.00 x 0.10 cm|
    | couriersplease_5kg_satchel | 5kg Satchel | 43.70 x 59.70 x 0.10 cm|
    """
    COURIERSPLEASE_500G_SATCHEL = 'couriersplease_500g_satchel'
    COURIERSPLEASE_1KG_SATCHEL = 'couriersplease_1kg_satchel'
    COURIERSPLEASE_3KG_SATCHEL = 'couriersplease_3kg_satchel'
    COURIERSPLEASE_5KG_SATCHEL = 'couriersplease_5kg_satchel'
