"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelSwyftEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | same_day | Next Day|
    | next_day | Next Day|
    """
    SAME_DAY = 'same_day'
    NEXT_DAY = 'next_day'
