"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ObjectStateEnum(str, Enum):
    r"""Indicates the validity of the enclosing object"""
    VALID = 'VALID'
    INVALID = 'INVALID'
