"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AddressValidationResultsMessageSourceEnum(str, Enum):
    SHIPPO_ADDRESS_VALIDATOR = 'Shippo Address Validator'
    UPS = 'UPS'
