"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ParcelTemplateFedExEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | FedEx_Box_10kg | FedEx® 10kg Box | 15.81 x 12.94 x 10.19 in|
    | FedEx_Box_25kg | FedEx® 25kg Box | 54.80 x 42.10 x 33.50 in|
    | FedEx_Box_Extra_Large_1 | FedEx® Extra Large Box (X1) | 11.88 x 11.00 x 10.75 in|
    | FedEx_Box_Extra_Large_2 | FedEx® Extra Large Box (X2) | 15.75 x 14.13 x 6.00 in|
    | FedEx_Box_Large_1 | FedEx® Large Box (L1) | 17.50 x 12.38 x 3.00 in|
    | FedEx_Box_Large_2 | FedEx® Large Box (L2) | 11.25 x 8.75 x 7.75 in|
    | FedEx_Box_Medium_1 | FedEx® Medium Box (M1) | 13.25 x 11.50 x 2.38 in|
    | FedEx_Box_Medium_2 | FedEx® Medium Box (M2) | 11.25 x 8.75 x 4.38 in|
    | FedEx_Box_Small_1 | FedEx® Small Box (S1) | 12.38 x 10.88 x 1.50 in|
    | FedEx_Box_Small_2 | FedEx® Small Box (S2) | 11.25 x 8.75 x 4.38 in|
    | FedEx_Envelope | FedEx® Envelope | 12.50 x 9.50 x 0.80 in|
    | FedEx_Padded_Pak | FedEx® Padded Pak | 11.75 x 14.75 x 2.00 in|
    | FedEx_Pak_1 | FedEx® Large Pak | 15.50 x 12.00 x 0.80 in|
    | FedEx_Pak_2 | FedEx® Small Pak | 12.75 x 10.25 x 0.80 in|
    | FedEx_Tube | FedEx® Tube | 38.00 x 6.00 x 6.00 in|
    | FedEx_XL_Pak | FedEx® Extra Large Pak | 17.50 x 20.75 x 2.00 in|
    """
    FED_EX_BOX_10KG = 'FedEx_Box_10kg'
    FED_EX_BOX_25KG = 'FedEx_Box_25kg'
    FED_EX_BOX_EXTRA_LARGE_1 = 'FedEx_Box_Extra_Large_1'
    FED_EX_BOX_EXTRA_LARGE_2 = 'FedEx_Box_Extra_Large_2'
    FED_EX_BOX_LARGE_1 = 'FedEx_Box_Large_1'
    FED_EX_BOX_LARGE_2 = 'FedEx_Box_Large_2'
    FED_EX_BOX_MEDIUM_1 = 'FedEx_Box_Medium_1'
    FED_EX_BOX_MEDIUM_2 = 'FedEx_Box_Medium_2'
    FED_EX_BOX_SMALL_1 = 'FedEx_Box_Small_1'
    FED_EX_BOX_SMALL_2 = 'FedEx_Box_Small_2'
    FED_EX_ENVELOPE = 'FedEx_Envelope'
    FED_EX_PADDED_PAK = 'FedEx_Padded_Pak'
    FED_EX_PAK_1 = 'FedEx_Pak_1'
    FED_EX_PAK_2 = 'FedEx_Pak_2'
    FED_EX_TUBE = 'FedEx_Tube'
    FED_EX_XL_PAK = 'FedEx_XL_Pak'
