"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelDHLGermanyEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | dhl_germany_europaket | DHL Germany Europaket|
    | dhl_germany_paket | DHL Germany Paket|
    | dhl_germany_paket_connect | DHL Germany Paket Connect|
    | dhl_germany_paket_international | DHL Germany Paket International|
    | dhl_germany_paket_priority | DHL Germany Paket Priority|
    | dhl_germany_paket_sameday | DHL Germany Paket Sameday|
    """
    DHL_GERMANY_EUROPAKET = 'dhl_germany_europaket'
    DHL_GERMANY_PAKET = 'dhl_germany_paket'
    DHL_GERMANY_PAKET_CONNECT = 'dhl_germany_paket_connect'
    DHL_GERMANY_PAKET_INTERNATIONAL = 'dhl_germany_paket_international'
    DHL_GERMANY_PAKET_PRIORITY = 'dhl_germany_paket_priority'
    DHL_GERMANY_PAKET_SAMEDAY = 'dhl_germany_paket_sameday'
