"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelCDLEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | cdl_next_day | Next Day|
    """
    CDL_NEXT_DAY = 'cdl_next_day'
