"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelDHLeCommerceEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | dhl_ecommerce_marketing_parcel_expedited | Marketing Parcel Expedited|
    | dhl_ecommerce_globalmail_business_ipa | GlobalMail Business IPA|
    | dhl_ecommerce_parcel_international_direct | Parcel International Direct|
    | dhl_ecommerce_parcels_expedited_max | Parcels Expedited Max|
    | dhl_ecommerce_bpm_ground | Bounded Printed Matter Ground|
    | dhl_ecommerce_priority_expedited | Priority Expedited|
    | dhl_ecommerce_globalmail_packet_ipa | GlobalMail Packet IPA|
    | dhl_ecommerce_globalmail_packet_isal | GlobalMail Packet ISAL|
    | dhl_ecommerce_easy_return_plus | Easy Return Plus|
    | dhl_ecommerce_marketing_parcel_ground | Marketing Parcel Ground|
    | dhl_ecommerce_first_class_parcel_expedited | First Class Parcel Expedited|
    | dhl_ecommerce_globalmail_business_priority | GlobalMail Business Priority|
    | dhl_ecommerce_parcels_expedited | Parcels Expedited|
    | dhl_ecommerce_globalmail_business_isal | GlobalMail Business ISAL|
    | dhl_ecommerce_parcel_plus_expedited_max | Parcel Plus Expedited Max|
    | dhl_ecommerce_globalmail_packet_plus | GlobalMail Packet Plus|
    | dhl_ecommerce_parcels_ground | Parcels Ground|
    | dhl_ecommerce_expedited | Expedited|
    | dhl_ecommerce_parcel_plus_ground | Parcel Plus Ground|
    | dhl_ecommerce_parcel_international_standard | Parcel International Standard|
    | dhl_ecommerce_bpm_expedited | Bounded Printed Matter Expedited|
    | dhl_ecommerce_parcel_international_expedited | Parcel International Expedited|
    | dhl_ecommerce_globalmail_packet_priority | GlobalMail Packet Priority|
    | dhl_ecommerce_easy_return_light | Easy Return Light|
    | dhl_ecommerce_parcel_plus_expedited | Parcel Plus Expedited|
    | dhl_ecommerce_globalmail_business_standard | GlobalMail Packet Standard|
    | dhl_ecommerce_ground | Ground|
    | dhl_ecommerce_globalmail_packet_standard | GlobalMail Business Standard|
    """
    DHL_ECOMMERCE_MARKETING_PARCEL_EXPEDITED = 'dhl_ecommerce_marketing_parcel_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_BUSINESS_IPA = 'dhl_ecommerce_globalmail_business_ipa'
    DHL_ECOMMERCE_PARCEL_INTERNATIONAL_DIRECT = 'dhl_ecommerce_parcel_international_direct'
    DHL_ECOMMERCE_PARCELS_EXPEDITED_MAX = 'dhl_ecommerce_parcels_expedited_max'
    DHL_ECOMMERCE_BPM_GROUND = 'dhl_ecommerce_bpm_ground'
    DHL_ECOMMERCE_PRIORITY_EXPEDITED = 'dhl_ecommerce_priority_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_PACKET_IPA = 'dhl_ecommerce_globalmail_packet_ipa'
    DHL_ECOMMERCE_GLOBALMAIL_PACKET_ISAL = 'dhl_ecommerce_globalmail_packet_isal'
    DHL_ECOMMERCE_EASY_RETURN_PLUS = 'dhl_ecommerce_easy_return_plus'
    DHL_ECOMMERCE_MARKETING_PARCEL_GROUND = 'dhl_ecommerce_marketing_parcel_ground'
    DHL_ECOMMERCE_FIRST_CLASS_PARCEL_EXPEDITED = 'dhl_ecommerce_first_class_parcel_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_BUSINESS_PRIORITY = 'dhl_ecommerce_globalmail_business_priority'
    DHL_ECOMMERCE_PARCELS_EXPEDITED = 'dhl_ecommerce_parcels_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_BUSINESS_ISAL = 'dhl_ecommerce_globalmail_business_isal'
    DHL_ECOMMERCE_PARCEL_PLUS_EXPEDITED_MAX = 'dhl_ecommerce_parcel_plus_expedited_max'
    DHL_ECOMMERCE_GLOBALMAIL_PACKET_PLUS = 'dhl_ecommerce_globalmail_packet_plus'
    DHL_ECOMMERCE_PARCELS_GROUND = 'dhl_ecommerce_parcels_ground'
    DHL_ECOMMERCE_EXPEDITED = 'dhl_ecommerce_expedited'
    DHL_ECOMMERCE_PARCEL_PLUS_GROUND = 'dhl_ecommerce_parcel_plus_ground'
    DHL_ECOMMERCE_PARCEL_INTERNATIONAL_STANDARD = 'dhl_ecommerce_parcel_international_standard'
    DHL_ECOMMERCE_BPM_EXPEDITED = 'dhl_ecommerce_bpm_expedited'
    DHL_ECOMMERCE_PARCEL_INTERNATIONAL_EXPEDITED = 'dhl_ecommerce_parcel_international_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_PACKET_PRIORITY = 'dhl_ecommerce_globalmail_packet_priority'
    DHL_ECOMMERCE_EASY_RETURN_LIGHT = 'dhl_ecommerce_easy_return_light'
    DHL_ECOMMERCE_PARCEL_PLUS_EXPEDITED = 'dhl_ecommerce_parcel_plus_expedited'
    DHL_ECOMMERCE_GLOBALMAIL_BUSINESS_STANDARD = 'dhl_ecommerce_globalmail_business_standard'
    DHL_ECOMMERCE_GROUND = 'dhl_ecommerce_ground'
    DHL_ECOMMERCE_GLOBALMAIL_PACKET_STANDARD = 'dhl_ecommerce_globalmail_packet_standard'
