"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ParcelTemplateDPDUKEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | DPD_UK_Express_Pak| DPD UK Express Pak | 530.00 x 400.00 x 100.00 mm|
    """
    DPD_UK_EXPRESS_PAK = 'DPD_UK_Express_Pak'
