"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .servicelevelairterraenum import ServiceLevelAirterraEnum
from .servicelevelapcpostalenum import ServiceLevelAPCPostalEnum
from .servicelevelapgenum import ServiceLevelAPGEnum
from .servicelevelaramexaustraliaenum import ServiceLevelAramexAustraliaEnum
from .servicelevelasendiaenum import ServiceLevelAsendiaEnum
from .servicelevelaustraliapostenum import ServiceLevelAustraliaPostEnum
from .servicelevelbettertrucksenum import ServiceLevelBetterTrucksEnum
from .servicelevelcanadapostenum import ServiceLevelCanadaPostEnum
from .servicelevelcdlenum import ServiceLevelCDLEnum
from .servicelevelchronopostenum import ServiceLevelChronopostEnum
from .servicelevelcolissimoenum import ServiceLevelColissimoEnum
from .servicelevelcorreosespanaenum import ServiceLevelCorreosEspanaEnum
from .servicelevelcourierspleaseenum import ServiceLevelCouriersPleaseEnum
from .serviceleveldeutschepostenum import ServiceLevelDeutschePostEnum
from .serviceleveldhlecommerceenum import ServiceLevelDHLeCommerceEnum
from .serviceleveldhlexpressenum import ServiceLevelDHLExpressEnum
from .serviceleveldhlgermanyenum import ServiceLevelDHLGermanyEnum
from .serviceleveldpddeenum import ServiceLevelDPDDEEnum
from .serviceleveldpdukenum import ServiceLevelDPDUKEnum
from .servicelevelepostglobalenum import ServiceLevelePostGlobalEnum
from .servicelevelevriukenum import ServiceLevelEvriUKEnum
from .servicelevelfedexenum import ServiceLevelFedExEnum
from .servicelevelglobegisticsenum import ServiceLevelGlobegisticsEnum
from .servicelevelglsusenum import ServiceLevelGLSUSEnum
from .serviceleveljitsuenum import ServiceLevelJitsuEnum
from .servicelevellasershipenum import ServiceLevelLasershipEnum
from .servicelevellsoenum import ServiceLevelLSOEnum
from .servicelevelmondialrelayenum import ServiceLevelMondialRelayEnum
from .servicelevelontracenum import ServiceLevelOnTracEnum
from .servicelevelparcelforceenum import ServiceLevelParcelforceEnum
from .servicelevelpostitalianeenum import ServiceLevelPostItalianeEnum
from .servicelevelpurolatorenum import ServiceLevelPurolatorEnum
from .servicelevelroyalmailenum import ServiceLevelRoyalMailEnum
from .servicelevelsendleenum import ServiceLevelSendleEnum
from .servicelevelswyftenum import ServiceLevelSwyftEnum
from .serviceleveludsenum import ServiceLevelUDSEnum
from .servicelevelupsenum import ServiceLevelUPSEnum
from .serviceleveluspsenum import ServiceLevelUSPSEnum
from .servicelevelvehoenum import ServiceLevelVehoEnum
from typing import Union

ServiceLevelEnumSet = Union[ServiceLevelUSPSEnum, ServiceLevelFedExEnum, ServiceLevelUPSEnum, ServiceLevelAirterraEnum, ServiceLevelAPCPostalEnum, ServiceLevelAsendiaEnum, ServiceLevelAustraliaPostEnum, ServiceLevelAPGEnum, ServiceLevelBetterTrucksEnum, ServiceLevelCanadaPostEnum, ServiceLevelCDLEnum, ServiceLevelChronopostEnum, ServiceLevelCouriersPleaseEnum, ServiceLevelCorreosEspanaEnum, ServiceLevelColissimoEnum, ServiceLevelPurolatorEnum, ServiceLevelDHLExpressEnum, ServiceLevelDHLeCommerceEnum, ServiceLevelDHLGermanyEnum, ServiceLevelDPDDEEnum, ServiceLevelDPDUKEnum, ServiceLevelDeutschePostEnum, ServiceLevelAramexAustraliaEnum, ServiceLevelGlobegisticsEnum, ServiceLevelGLSUSEnum, ServiceLevelLSOEnum, ServiceLevelMondialRelayEnum, ServiceLevelParcelforceEnum, ServiceLevelPostItalianeEnum, ServiceLevelePostGlobalEnum, ServiceLevelRoyalMailEnum, ServiceLevelSendleEnum, ServiceLevelOnTracEnum, ServiceLevelJitsuEnum, ServiceLevelLasershipEnum, ServiceLevelEvriUKEnum, ServiceLevelUDSEnum, ServiceLevelVehoEnum, ServiceLevelSwyftEnum]
