"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelParcelforceEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | parcelforce_express48 | Express 48|
    | parcelforce_express24 | Express 24|
    | parcelforce_expressam | Express AM|
    """
    PARCELFORCE_EXPRESS48 = 'parcelforce_express48'
    PARCELFORCE_EXPRESS24 = 'parcelforce_express24'
    PARCELFORCE_EXPRESSAM = 'parcelforce_expressam'
