"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ParcelTemplateDHLeCommerceEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | DHLeC_Irregular | Irregular Shipment | 10.00 x 10.00 x 10.00 in|
    | DHLeC_SM_Flats | Flats | 27.00 x 17.00 x 17.00 in|
    """
    DH_LE_C_IRREGULAR = 'DHLeC_Irregular'
    DH_LE_C_SM_FLATS = 'DHLeC_SM_Flats'
