"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelCouriersPleaseEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | couriersplease_domestic_priority_auth_to_leave | Domestic Priority - Authority To Leave/POPPoints|
    | couriersplease_domestic_priority_sign_required | Domestic Priority - Signature Required|
    | couriersplease_gold_domestic_auth_to_leave | Gold Domestic - Authority To Leave/POPPoints|
    | couriersplease_gold_domestic_sign_required | Gold Domestic - Signature Required|
    | couriersplease_off_peak_auth_to_leave | Off Peak - Authority To Leave/POPPoints|
    | couriersplease_off_peak_sign_required | Off Peak - Signature Required|
    | couriersplease_parcel_auth_to_leave | Parcel - Authority To Leave|
    | couriersplease_parcel_sign_required | Parcel - Signature Required|
    | couriersplease_road_express | Road Express|
    | couriersplease_satchel_auth_to_leave | Satchel - Authority To Leave|
    | couriersplease_satchel_sign_required | Satchel - Signature Required|
    """
    COURIERSPLEASE_DOMESTIC_PRIORITY_AUTH_TO_LEAVE = 'couriersplease_domestic_priority_auth_to_leave'
    COURIERSPLEASE_DOMESTIC_PRIORITY_SIGN_REQUIRED = 'couriersplease_domestic_priority_sign_required'
    COURIERSPLEASE_GOLD_DOMESTIC_AUTH_TO_LEAVE = 'couriersplease_gold_domestic_auth_to_leave'
    COURIERSPLEASE_GOLD_DOMESTIC_SIGN_REQUIRED = 'couriersplease_gold_domestic_sign_required'
    COURIERSPLEASE_OFF_PEAK_AUTH_TO_LEAVE = 'couriersplease_off_peak_auth_to_leave'
    COURIERSPLEASE_OFF_PEAK_SIGN_REQUIRED = 'couriersplease_off_peak_sign_required'
    COURIERSPLEASE_PARCEL_AUTH_TO_LEAVE = 'couriersplease_parcel_auth_to_leave'
    COURIERSPLEASE_PARCEL_SIGN_REQUIRED = 'couriersplease_parcel_sign_required'
    COURIERSPLEASE_ROAD_EXPRESS = 'couriersplease_road_express'
    COURIERSPLEASE_SATCHEL_AUTH_TO_LEAVE = 'couriersplease_satchel_auth_to_leave'
    COURIERSPLEASE_SATCHEL_SIGN_REQUIRED = 'couriersplease_satchel_sign_required'
