"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelAPGEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | epacket | ePacket|
    | epacket_plus | ePacket Plus|
    | eparcel_premium | eParcel premium|
    | apg_eparcel_expedited | eParcel Expedited|
    """
    EPACKET = 'epacket'
    EPACKET_PLUS = 'epacket_plus'
    EPARCEL_PREMIUM = 'eparcel_premium'
    APG_EPARCEL_EXPEDITED = 'apg_eparcel_expedited'
