"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelMondialRelayEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | mondial_relay_pointrelais | Point Relais|
    """
    MONDIAL_RELAY_POINTRELAIS = 'mondial_relay_pointrelais'
