"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from shippo import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class FedExConnectExistingOwnAccountParameters:
    first_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('first_name') }})
    r"""First name of the account holder"""
    last_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('last_name') }})
    r"""Last name of the account holder"""
    phone_number: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('phone_number') }})
    r"""Phone number of the account holder"""
    from_address_st: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from_address_st') }})
    r"""Street address of the account holder"""
    from_address_city: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from_address_city') }})
    r"""City of the account holder"""
    from_address_state: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from_address_state') }})
    r"""State of the account holder"""
    from_address_zip: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from_address_zip') }})
    r"""Zip code of the account holder"""
    from_address_country_iso2: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from_address_country_iso2') }})
    r"""Country of the account holder"""
    

